complete -c dunst -s v -l version -o version -d 'Print version'
complete -c dunst -o verbosity -x -a 'crit warn mesg info debug' -d 'Minimum level for message'
complete -c dunst -o conf -o config -d 'Path to configuration file'
complete -c dunst -o print -l print -d 'Print notifications to stdout'
complete -c dunst -o startup_notification -l startup_notification -d 'Display a notification on startup'
complete -c dunst -s h -l help -o help -d 'Print help'

# ex: filetype=fish
